@@ -3,7 +3,7 @@ from flask.views import MethodView
 
 from werkzeug import exceptions as exc
 
-from ifile.manage import client as client_api
+from ifile import client as client_api
 
 
 class Client(MethodView):
